import { type ComposableStyles, ElementStyles, type ElementViewTemplate, FASTElementDefinition, type ShadowRootOptions } from '@microsoft/fast-element';
import type { StaticallyComposableHTML } from "@microsoft/fast-foundation";
import { type ComponentAnatomy, StyleRules } from "@adaptive-web/adaptive-ui";
import type { AccordionItemStatics, BreadcrumbItemStatics, CheckboxStatics, ComboboxStatics, FlipperStatics, MenuItemStatics, NumberFieldStatics, RadioStatics, SelectStatics, TreeItemStatics } from "./components/index.js";
type ComponentStatics = AccordionItemStatics | BreadcrumbItemStatics | CheckboxStatics | ComboboxStatics | FlipperStatics | MenuItemStatics | NumberFieldStatics | RadioStatics | SelectStatics | TreeItemStatics;
/**
 * Represents partial metadata configuration for a custom element.
 *
 * @beta
 */
export type PartialDesignSystem = Partial<DesignSystem>;
/**
 * @beta
 */
export type ElementStaticMap = Map<ComponentStatics, StaticallyComposableHTML>;
/**
 * Represents metadata configuration for a custom element.
 *
 * @beta
 */
export declare class DesignSystem {
    private _prefix;
    private _registry;
    private _statics;
    constructor(_prefix: string, _registry?: CustomElementRegistry, _statics?: ElementStaticMap);
    get prefix(): string;
    get registry(): CustomElementRegistry;
    get statics(): ElementStaticMap;
    /**
     * Overrides DesignSystem properties.
     *
     * @beta
     */
    configure(options: PartialDesignSystem): this;
    /**
     * Sets the element prefix.
     *
     * @remarks
     * Can be chained with other methods on the DesignSystem class.
     *
     * @beta
     */
    withPrefix(prefix: string): this;
    /**
     * Defines a set of components using the prefix and registry defined with the DesignSystem
     *
     * @beta
     */
    defineComponents(components: Record<string, ((ds: DesignSystem) => FASTElementDefinition) | FASTElementDefinition>): void;
    /**
     * Checks a StyleRule for a target `part` and turns it into a class name.
     *
     * @remarks
     * This Design System is local to AWC and all templates and anatomy are structured this way.
     * The opinion of using class names used to exist in AUI, but AUI is now non-opinionated in this regard.
     *
     * @param styleRule - The StyleRule to check and update
     * @returns The updated StyleRule.
     */
    private static updateStyleRulesParts;
    /**
     * Checks a `StyleModuleTarget` for `part` and turns it into a class name.
     *
     * @remarks
     * This Design System is local to AWC and all templates and anatomy are structured this way.
     * The opinion of using class names used to exist in AUI, but AUI is now non-opinionated in this regard.
     *
     * @param styleRule - The StyleModuleTarget to check and update
     * @returns The updated StyleModuleTarget.
     */
    private static updateTargetParts;
    /**
     * Assembles the collection of intended styles, evaluating and injecting modular styling if provided.
     *
     * @param defaultStyles - The default collection of styles to use if not overridden by `options.styles`.
     * @param interactivity - The interactivity selectors for the component.
     * @param options - The component options, using `styles` and `styleModules`.
     * @returns The collection of desired styles.
     *
     * @beta
     */
    static assembleStyles(defaultStyles: ComposableStyles[], anatomy?: ComponentAnatomy<any, any>, options?: ComposeOptions<any>): ElementStyles;
}
/**
 * The default {@link DesignSystem} configuration.
 *
 * @beta
 */
export declare const DefaultDesignSystem: DesignSystem;
/**
 * Configuration options for composing an element definition.
 *
 * @internal
 */
export type ComposeOptions<TSource, TStatics extends string = any> = {
    template?: (ds: DesignSystem) => ElementViewTemplate<TSource, any>;
    styles?: ElementStyles | ElementStyles[];
    styleModules?: StyleRules;
    shadowOptions?: Partial<ShadowRootOptions>;
    elementOptions?: ElementDefinitionOptions;
    statics?: Record<TStatics, StaticallyComposableHTML>;
};
export {};
