import { elements, html, ref, slotted, when } from "@microsoft/fast-element";
import { endSlotTemplate, MenuItemRole, startSlotTemplate, staticallyCompose, } from "@microsoft/fast-foundation";
import { Focus, Interactivity } from "@adaptive-web/adaptive-ui";
/**
 * Keys for {@link DesignSystem} `statics` registration for the menu item.
 *
 * @beta
 */
export const MenuItemStatics = {
    checkbox: "menu-item-checkbox-indicator",
    radio: "menu-item-radio-indicator",
    submenu: "menu-item-submenu-item"
};
/**
 * @public
 */
export const MenuItemConditions = {
    checked: "[aria-checked='true']",
};
/**
 * @public
 */
export const MenuItemParts = {
    content: "content",
    submenuIcon: "submenu-icon",
};
/**
 * @public
 */
export const MenuItemAnatomy = {
    interactivity: Interactivity.disabledAttribute,
    conditions: MenuItemConditions,
    parts: MenuItemParts,
    focus: Focus.contextFocused(),
};
// TODO: Temporary copy of template until https://github.com/microsoft/fast/pull/6286/
/**
 * Default Menu Item template, {@link @microsoft/fast-foundation#menuItemTemplate}.
 * @public
 */
export const template = (ds) => {
    const options = {
        checkboxIndicator: ds.statics.get(MenuItemStatics.checkbox),
        radioIndicator: ds.statics.get(MenuItemStatics.radio),
        expandCollapseGlyph: ds.statics.get(MenuItemStatics.submenu),
    };
    const templateCache = new Map();
    function setTemplateByRole(role, options) {
        let existing = templateCache.get(role);
        if (!existing) {
            const key = role.replace("menuitem", "");
            const optionsKey = key + "Indicator";
            existing = html `
                    <span part="${key}-indicator" class="${key}-indicator">
                        <slot name="${key}-indicator">
                            ${staticallyCompose(options[optionsKey])}
                        </slot>
                    </span>
                `;
            templateCache.set(role, existing);
        }
        return existing;
    }
    return html `
            <template
                aria-haspopup="${x => (x.hasSubmenu ? "menu" : void 0)}"
                aria-checked="${x => (x.role !== MenuItemRole.menuitem ? x.checked : void 0)}"
                aria-disabled="${x => x.disabled}"
                aria-expanded="${x => x.expanded}"
                @keydown="${(x, c) => x.handleMenuItemKeyDown(c.event)}"
                @click="${(x, c) => x.handleMenuItemClick(c.event)}"
                @mouseover="${(x, c) => x.handleMouseOver(c.event)}"
                @mouseout="${(x, c) => x.handleMouseOut(c.event)}"
            >
                ${when(x => x.role !== MenuItemRole.menuitem, html `
                        ${x => setTemplateByRole(x.role, options)}
                    `)}
                ${startSlotTemplate(options)}
                <span class="content" part="content">
                    <slot></slot>
                </span>
                ${endSlotTemplate(options)}
                ${when(x => x.hasSubmenu, html `
                        <span part="submenu-icon" class="submenu-icon">
                            <slot name="submenu-icon">
                                ${staticallyCompose(options.expandCollapseGlyph)}
                            </slot>
                        </span>
                    `)}
                <span
                    ?hidden="${x => !x.expanded}"
                    class="submenu-container"
                    part="submenu-container"
                    ${ref("submenuContainer")}
                >
                    <slot
                        name="submenu"
                        ${slotted({
        property: "slottedSubmenu",
        filter: elements("[role='menu']"),
    })}
                    ></slot>
                </span>
            </template>
        `;
};
//# sourceMappingURL=menu-item.template.js.map